########
Examples
########

This page contains some examples that are ready to run. 
You can find all examples scripts in the directory `$MOLA/examples`, 
where `$MOLA` is the install repository of MOLA, defined when MOLA environment is sourced.

.. admonition:: :fas:`warning` Disclaimer :fas:`warning`

   Examples presented here aim to be representative of possible real simulations, 
   to serve as templates for users. However, in order to keep relatively light data files, 
   meshes that are used are not fine enough to give results that could be considered as 
   reliable or well converged.  

.. toctree::
   :maxdepth: 2

   airplane/index
   linear_cascade/index
   propeller/index
   turbomachinery/index

